@@ -12,7 +12,7 @@ use Data::Dumper;
 
 use Magrathea::API::Abbreviation qw{abbreviate};
 
-use constant POSTCODE => qr/^([Gg][Ii][Rr] 0[Aa]{2})|((([A-Za-z][0-9]{1,2})|(([A-Za-z][A-Ha-hJ-Yj-y][0-9]{1,2})|(([A-Za-z][0-9][A-Za-z])|([A-Za-z][A-Ha-hJ-Yj-y][0-9]?[A-Za-z])))) [0-9][A-Za-z]{2})$/;
+use constant POSTCODE_RE => qr/^([Gg][Ii][Rr] 0[Aa]{2})|((([A-Za-z][0-9]{1,2})|(([A-Za-z][A-Ha-hJ-Yj-y][0-9]{1,2})|(([A-Za-z][0-9][A-Za-z])|([A-Za-z][A-Ha-hJ-Yj-y][0-9]?[A-Za-z])))) [0-9][A-Za-z]{2})$/;
 
 =encoding utf8
 
@@ -230,8 +230,11 @@ sub postcode
     my $self = shift;
     my $postcode = shift;
     if ($postcode) {
-        croak "Invalid postcode" unless $postcode =~ POSTCODE;
+        if ($postcode ne "") {
+            croak "Invalid postcode" unless $postcode =~ POSTCODE_RE;
+        }
         $self->{info}{postcode} = $postcode;
+        $self->POSTCODE($postcode);
     }
     return $self->{info}{postcode};
 }
@@ -286,7 +289,7 @@ sub AUTOLOAD
     my $commands = qr{^(?:
     CREATE|VALIDATE|STATUS|DATA|
     TITLE|FORENAME|NAME|HONOURS|BUSSUFFIX|
-    PREMISES|THOOROUGHFARE|LOCALITY|POSTCODE
+    PREMISES|THOROUGHFARE|LOCALITY|POSTCODE
     )$}x;
     my %fields = (
         title => 20,
@@ -309,7 +312,7 @@ sub AUTOLOAD
     else {
         my $value = shift;
         croak "Unknown method: $name" unless exists $fields{$name};
-        if ($value) {
+        if (defined $value) {
             my $abbr = abbreviate $value;
             my $len = length $abbr;
             my $max = $fields{$name};
@@ -317,6 +320,8 @@ sub AUTOLOAD
             "is longer than the max. length of $max" .
             "for field $name" if $len > $max;
             $self->{info}{$name} = $abbr;
+            my $cmd = uc $name;
+            $self->$cmd($abbr);
         }
         return $self->{info}{$name};
     }
